package TestApp::View::Xslate::Appconfig;

use strict;
use base 'Catalyst::View::Xslate';

__PACKAGE__->config(
  verbose => 0,
  type => 'text',
);

1;
